@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::DataCleansing::Object;
 
-our $VERSION = 0.003; # VERSION
+our $VERSION = 0.004; # VERSION
 
 our $results = [
   [
@@ -9,147 +9,163 @@ our $results = [
     [
       {
         dataset     => "ary10k-u1-obj",
-        errors      => 9.4e-06,
+        errors      => 5.4e-06,
+        p_tags      => "",
         participant => "JSON::PP",
-        rate        => 220,
-        samples     => 20,
-        time        => 4.5,
+        rate        => 165,
+        samples     => 21,
+        time        => 6.06,
         vs_slowest  => 1,
       },
       {
         dataset     => "ary10k-u10k-obj",
-        errors      => 8.5e-06,
+        errors      => 1.8e-06,
+        p_tags      => "inplace",
         participant => "Data::Rmap",
-        rate        => 310,
+        rate        => 219,
         samples     => 20,
-        time        => 3.2,
+        time        => 4.57,
+        vs_slowest  => 1.33,
+      },
+      {
+        dataset     => "ary10k-u10k-obj",
+        errors      => 6e-06,
+        p_tags      => "",
+        participant => "JSON::PP",
+        rate        => 240,
+        samples     => 20,
+        time        => 4.2,
         vs_slowest  => 1.4,
       },
-      {
-        dataset     => "ary10k-u10k-obj",
-        errors      => 2.7e-06,
-        participant => "JSON::PP",
-        rate        => 323,
-        samples     => 20,
-        time        => 3.1,
-        vs_slowest  => 1.46,
-      },
       {
         dataset     => "ary10k-u1-obj",
-        errors      => 6.1e-06,
+        errors      => 1.5e-06,
+        p_tags      => "inplace",
         participant => "Data::Rmap",
-        rate        => 620,
+        rate        => 441,
         samples     => 20,
-        time        => 1.6,
-        vs_slowest  => 2.8,
+        time        => 2.27,
+        vs_slowest  => 2.67,
       },
       {
         dataset     => "ary10k-u10k-obj",
         errors      => 4.8e-07,
+        p_tags      => "",
         participant => "Data::Clean-clone",
-        rate        => 1130,
+        rate        => 752,
         samples     => 20,
-        time        => 0.884,
-        vs_slowest  => 5.12,
+        time        => 1.33,
+        vs_slowest  => 4.56,
       },
       {
         dataset     => "ary10k-u10k-obj",
-        errors      => 2.7e-07,
+        errors      => 1.3e-06,
+        p_tags      => "inplace",
         participant => "Data::Clean-inplace",
-        rate        => 1450,
-        samples     => 20,
-        time        => 0.688,
-        vs_slowest  => 6.58,
+        rate        => 990,
+        samples     => 22,
+        time        => 1,
+        vs_slowest  => 6,
       },
       {
         dataset     => "ary100-u1-obj",
-        errors      => 4.5e-07,
-        participant => "JSON::PP",
-        rate        => 2300,
-        samples     => 23,
-        time        => 0.43,
-        vs_slowest  => 11,
-      },
-      {
-        dataset     => "ary100-u100-obj",
         errors      => 6.2e-07,
+        p_tags      => "",
         participant => "JSON::PP",
-        rate        => 3100,
+        rate        => 1560,
         samples     => 21,
-        time        => 0.32,
-        vs_slowest  => 14,
+        time        => 0.64,
+        vs_slowest  => 9.47,
       },
       {
         dataset     => "ary100-u100-obj",
-        errors      => 4.3e-07,
+        errors      => 1.9e-07,
+        p_tags      => "",
+        participant => "JSON::PP",
+        rate        => 2020,
+        samples     => 24,
+        time        => 0.494,
+        vs_slowest  => 12.3,
+      },
+      {
+        dataset     => "ary100-u100-obj",
+        errors      => 8.5e-07,
+        p_tags      => "inplace",
         participant => "Data::Rmap",
-        rate        => 3100,
+        rate        => 2200,
         samples     => 20,
-        time        => 0.32,
-        vs_slowest  => 14,
+        time        => 0.46,
+        vs_slowest  => 13,
       },
       {
         dataset     => "ary10k-u1-obj",
-        errors      => 4.2e-07,
+        errors      => 6e-07,
+        p_tags      => "",
         participant => "Data::Clean-clone",
-        rate        => 4800,
-        samples     => 21,
-        time        => 0.21,
-        vs_slowest  => 22,
+        rate        => 3100,
+        samples     => 23,
+        time        => 0.32,
+        vs_slowest  => 19,
       },
       {
         dataset     => "ary10k-u1-obj",
-        errors      => 4.3e-07,
+        errors      => 4.3e-06,
+        p_tags      => "inplace",
         participant => "Data::Clean-inplace",
-        rate        => 5700,
+        rate        => 4000,
+        samples     => 37,
+        time        => 0.3,
+        vs_slowest  => 20,
+      },
+      {
+        dataset     => "ary100-u1-obj",
+        errors      => 1.4e-06,
+        p_tags      => "inplace",
+        participant => "Data::Rmap",
+        rate        => 4300,
         samples     => 20,
-        time        => 0.18,
+        time        => 0.23,
         vs_slowest  => 26,
       },
       {
-        dataset     => "ary100-u1-obj",
-        errors      => 4.8e-07,
-        participant => "Data::Rmap",
-        rate        => 6100,
+        dataset     => "ary100-u100-obj",
+        errors      => 2.1e-07,
+        p_tags      => "",
+        participant => "Data::Clean-clone",
+        rate        => 7100,
         samples     => 20,
-        time        => 0.16,
-        vs_slowest  => 28,
+        time        => 0.14,
+        vs_slowest  => 43,
       },
       {
         dataset     => "ary100-u100-obj",
-        errors      => 0,
-        participant => "Data::Clean-clone",
-        rate        => 10893.1,
-        samples     => 27,
-        time        => 0.0918013,
-        vs_slowest  => 49.3177,
-      },
-      {
-        dataset     => "ary100-u100-obj",
-        errors      => 2.7e-08,
+        errors      => 2.6e-08,
+        p_tags      => "inplace",
         participant => "Data::Clean-inplace",
-        rate        => 13100,
-        samples     => 20,
-        time        => 0.0763,
-        vs_slowest  => 59.3,
+        rate        => 10600,
+        samples     => 21,
+        time        => 0.0939,
+        vs_slowest  => 64.5,
       },
       {
         dataset     => "ary100-u1-obj",
-        errors      => 3.3e-08,
+        errors      => 1.1e-11,
+        p_tags      => "",
         participant => "Data::Clean-clone",
-        rate        => 42000,
+        rate        => 27792.1,
         samples     => 20,
-        time        => 0.024,
-        vs_slowest  => 190,
+        time        => 0.0359814,
+        vs_slowest  => 168.432,
       },
       {
         dataset     => "ary100-u1-obj",
-        errors      => 3.3e-08,
+        errors      => 1e-07,
+        p_tags      => "inplace",
         participant => "Data::Clean-inplace",
-        rate        => 53000,
+        rate        => 38000,
         samples     => 20,
-        time        => 0.019,
-        vs_slowest  => 240,
+        time        => 0.026,
+        vs_slowest  => 230,
       },
     ],
     {
@@ -159,6 +175,7 @@ our $results = [
                                             scenario_module => "DataCleansing::Object",
                                           },
       "func.bencher_version"           => undef,
+      "func.code_startup"              => undef,
       "func.cpu_info"                  => [
                                             {
                                               address_width                => 64,
@@ -272,7 +289,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2822.914,
+                                              speed                        => "2100.000",
                                               stepping                     => 4,
                                             },
                                             {
@@ -387,7 +404,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => "2606.460",
+                                              speed                        => 2199.968,
                                               stepping                     => 4,
                                             },
                                             {
@@ -502,7 +519,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2777.195,
+                                              speed                        => 1999.976,
                                               stepping                     => 4,
                                             },
                                             {
@@ -617,18 +634,18 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2599.953,
+                                              speed                        => 2199.968,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.827332973480225,
+      "func.elapsed_time"              => 0.963568925857544,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                              => 1.034,
+                                            "__PACKAGE__"                              => "1.040",
                                             "Acme::Damn"                               => 0.08,
                                             "Bencher::Scenario::DataCleansing::Object" => undef,
                                             "Benchmark::Dumb"                          => "0.10",
-                                            "Data::Clean"                              => 0.48,
+                                            "Data::Clean"                              => 0.49,
                                             "Data::Rmap"                               => 0.64,
                                             "Devel::Platform::Info"                    => 0.16,
                                             "JSON::PP"                                 => "2.27300",
@@ -667,14 +684,24 @@ our $results = [
       "func.scenario_module_mtime"     => 1484501473,
       "func.scenario_module_sha1sum"   => "7f311f4a8ce4352a3c84f338755e13527f8ca7ba",
       "func.scenario_module_sha256sum" => "7d2d523ff2657a046f88a6f13b56778c9a4ddd4e0093ca73b0aec59f63eda4a4",
-      "func.time_end"                  => 1485328285.86648,
+      "func.time_end"                  => 1503647414.14076,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485328285.03914,
-      "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
-      "table.field_units"              => [undef, undef, "/s", "ms"],
+      "func.time_start"                => 1503647413.1772,
+      "table.field_aligns"             => [
+                                            "left",
+                                            "left",
+                                            "left",
+                                            "number",
+                                            "number",
+                                            "number",
+                                            "number",
+                                            "number",
+                                          ],
+      "table.field_units"              => [undef, undef, undef, "/s", "ms"],
       "table.fields"                   => [
                                             "participant",
                                             "dataset",
+                                            "p_tags",
                                             "rate",
                                             "time",
                                             "vs_slowest",
