@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::DataCleansing::Startup;
 
-our $VERSION = 0.003; # VERSION
+our $VERSION = 0.004; # VERSION
 
 our $results = [
   [
@@ -8,114 +8,125 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0004,
-        mod_overhead_time => 164.1,
+        errors => 0.00045,
+        mod_overhead_time => 202.4,
         participant => "Data::Visitor::Callback",
-        proc_private_dirty_size => 0.82,
-        proc_rss_size => 4.1,
-        proc_size => 16,
+        proc_private_dirty_size => 3.1,
+        proc_rss_size => 6.5,
+        proc_size => 22,
         samples => 20,
-        time => 170,
+        time => 210,
         vs_slowest => 1,
       },
       {
-        errors => 6e-05,
-        mod_overhead_time => 17.1,
+        errors => 0.00013,
+        mod_overhead_time => 26.4,
+        participant => "Data::Tersify",
+        proc_private_dirty_size => 0.82,
+        proc_rss_size => 4.2,
+        proc_size => 16,
+        samples => 20,
+        time => 34,
+        vs_slowest => 6,
+      },
+      {
+        errors => 9e-05,
+        mod_overhead_time => 21.4,
         participant => "JSON::PP",
         proc_private_dirty_size => 1.3,
-        proc_rss_size => 4.7,
+        proc_rss_size => 4.8,
         proc_size => 20,
         samples => 20,
-        time => 23,
-        vs_slowest => 7.4,
+        time => 29,
+        vs_slowest => 7.2,
       },
       {
-        errors => 8.2e-05,
-        mod_overhead_time => 11.1,
+        errors => 1.9e-05,
+        mod_overhead_time => 12.9,
         participant => "JSON::MaybeXS",
-        proc_private_dirty_size => 3.1,
-        proc_rss_size => 6.6,
-        proc_size => 22,
+        proc_private_dirty_size => 3.12,
+        proc_rss_size => 6.68,
+        proc_size => 22.3,
         samples => 20,
-        time => 17,
-        vs_slowest => 9.8,
+        time => 20.5,
+        vs_slowest => 10,
       },
       {
-        errors => 5.9e-05,
-        mod_overhead_time => 10.1,
+        errors => 4.7e-05,
+        mod_overhead_time => 11.4,
         participant => "Data::Abridge",
         proc_private_dirty_size => 16,
         proc_rss_size => 19,
         proc_size => 55,
         samples => 20,
-        time => 16,
+        time => 19,
         vs_slowest => 11,
       },
       {
-        errors => 7.8e-05,
-        mod_overhead_time => 7.1,
-        participant => "Data::Rmap",
-        proc_private_dirty_size => 1.7,
-        proc_rss_size => 5.2,
-        proc_size => 19,
+        errors => 6.5e-05,
+        mod_overhead_time => 8.4,
+        participant => "JSON::XS",
+        proc_private_dirty_size => 1.3,
+        proc_rss_size => 4.8,
+        proc_size => 20,
         samples => 20,
-        time => 13,
+        time => 16,
         vs_slowest => 13,
       },
       {
-        errors => 5.3e-05,
-        mod_overhead_time => 7.1,
-        participant => "JSON::XS",
-        proc_private_dirty_size => 1.3,
-        proc_rss_size => 4.7,
-        proc_size => 20,
-        samples => 20,
-        time => 13,
-        vs_slowest => 14,
+        errors => 5.7e-05,
+        mod_overhead_time => 8.4,
+        participant => "Data::Rmap",
+        proc_private_dirty_size => 1.7,
+        proc_rss_size => 5.1,
+        proc_size => 19,
+        samples => 21,
+        time => 16,
+        vs_slowest => 13,
       },
       {
-        errors => 4.6e-05,
-        mod_overhead_time => 6.1,
+        errors => 4.5e-05,
+        mod_overhead_time => 7.4,
         participant => "Cpanel::JSON::XS",
         proc_private_dirty_size => 1.4,
         proc_rss_size => 4.8,
         proc_size => 19,
-        samples => 20,
-        time => 12,
+        samples => 22,
+        time => 15,
         vs_slowest => 14,
       },
       {
-        errors => 2.9e-05,
-        mod_overhead_time => 6.1,
+        errors => 4.3e-05,
+        mod_overhead_time => 7.4,
         participant => "Data::Clean::JSON",
         proc_private_dirty_size => 1.9,
-        proc_rss_size => 5.5,
+        proc_rss_size => 5.4,
         proc_size => 23,
         samples => 20,
-        time => 12,
-        vs_slowest => 15,
+        time => 15,
+        vs_slowest => 14,
       },
       {
-        errors => 5.9e-05,
-        mod_overhead_time => 4.1,
+        errors => 3.7e-05,
+        mod_overhead_time => 4.4,
         participant => "Data::Clean",
         proc_private_dirty_size => 1.3,
         proc_rss_size => 4.7,
         proc_size => 16,
         samples => 20,
-        time => 10,
-        vs_slowest => 17,
+        time => 12,
+        vs_slowest => 16,
       },
       {
-        errors => 1.3e-05,
+        errors => 1.6e-05,
         mod_overhead_time => 0,
         participant => "perl -e1 (baseline)",
         proc_private_dirty_size => 1.1,
         proc_rss_size => 4.5,
         proc_size => 16,
         samples => 20,
-        time => 5.9,
-        vs_slowest => 29,
+        time => 7.6,
+        vs_slowest => 27,
       },
     ],
     {
@@ -125,6 +136,7 @@ our $results = [
                                             scenario_module => "DataCleansing::Startup",
                                           },
       "func.bencher_version"           => undef,
+      "func.code_startup"              => undef,
       "func.cpu_info"                  => [
                                             {
                                               address_width                => 64,
@@ -238,7 +250,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => "2854.960",
+                                              speed                        => "2261.710",
                                               stepping                     => 4,
                                             },
                                             {
@@ -353,7 +365,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2600.007,
+                                              speed                        => "2231.250",
                                               stepping                     => 4,
                                             },
                                             {
@@ -468,7 +480,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2599.953,
+                                              speed                        => 2229.609,
                                               stepping                     => 4,
                                             },
                                             {
@@ -583,21 +595,22 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2600.007,
+                                              speed                        => 2260.125,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 6.69379591941833,
+      "func.elapsed_time"              => 9.89527297019958,
       "func.module_startup"            => 1,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                               => 1.034,
+                                            "__PACKAGE__"                               => "1.040",
                                             "Bencher::Scenario::DataCleansing::Startup" => undef,
                                             "Benchmark::Dumb"                           => "0.10",
                                             "Cpanel::JSON::XS"                          => 3.0217,
                                             "Data::Abridge"                             => "0.03.01",
-                                            "Data::Clean"                               => 0.48,
+                                            "Data::Clean"                               => 0.49,
                                             "Data::Clean::JSON"                         => 0.38,
                                             "Data::Rmap"                                => 0.64,
+                                            "Data::Tersify"                             => 0.001,
                                             "Data::Visitor::Callback"                   => "0.30",
                                             "Devel::Platform::Info"                     => 0.16,
                                             "JSON::MaybeXS"                             => 1.003005,
@@ -607,7 +620,7 @@ our $results = [
                                             "Sys::Info"                                 => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 9]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 10]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "rosa",
@@ -633,13 +646,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::DataCleansing::Startup",
-      "func.scenario_module_md5sum"    => "7b1ab4ceed2eda85dc6c17412881f540",
-      "func.scenario_module_mtime"     => 1484501473,
-      "func.scenario_module_sha1sum"   => "31046707b5c4c08084e8e49ebf94a9b1866fb9c4",
-      "func.scenario_module_sha256sum" => "fbc91fe99bb671066cb06310951edec49da3cf839228e33c8d11d5685ddc7a94",
-      "func.time_end"                  => 1485328295.34262,
+      "func.scenario_module_md5sum"    => "3cf33ed3849fb0e0a5d2d3fe50a3bfd2",
+      "func.scenario_module_mtime"     => 1503646392,
+      "func.scenario_module_sha1sum"   => "e1182776d6d599ac1fdf74bc1a63c6b0857b5460",
+      "func.scenario_module_sha256sum" => "237108e4292ac776e1bbab5dbf8f4b05de0b5959f0dcfd742b8b3e2b1acec206",
+      "func.time_end"                  => 1503647434.9659,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485328288.64883,
+      "func.time_start"                => 1503647425.07063,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
